@@ -2,18 +2,12 @@ package Mojolicious::Plugin::Ident::Response;
 
 use strict;
 use warnings;
-use Mojo::Base -base;
+use base qw( AnyEvent::Ident::Response );
 
 # ABSTRACT: Ident response object
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 
-has 'os';
-has 'username';
-
-# private attributes (undocumented may go away)
-has 'remote_address';
-
 my $server_user_uid;
 my $server_user_name;
 
@@ -40,7 +34,7 @@ sub _setup
 sub same_user
 {
   my($self) = @_;
-  return unless $self->remote_address eq '127.0.0.1';
+  return unless $self->{remote_address} eq '127.0.0.1';
   return 1 if $self->username eq $server_user_name;
   return 1 if defined $server_user_uid && $self->username =~ /^\d+$/ && $self->username == $server_user_uid;
   return;
@@ -58,18 +52,15 @@ Mojolicious::Plugin::Ident::Response - Ident response object
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 DESCRIPTION
 
+L<Mojolicious::Plugin::Ident::Response> is a L<AnyEvent::Ident::Response>.
+
 This class represents the responses as they come back
 from the remote ident server.
 
-NOTE: This class is only used for blocking requests.
-If you provide a callback, then you are probably 
-more interested in L<AnyEvent::Ident::Response>, which
-is similar, but does not have a C<same_user> method.
-
 =head1 ATTRIBUTES
 
 =head2 $ident-E<gt>username
@@ -82,6 +73,18 @@ the remote ident server.
 The operating system of the remote connection as provided
 by the remote ident server.
 
+=head2 $ident-E<gt>is_success
+
+True if the ident response was not an error.  Only
+useful in non-blocking mode, as in blocking mode an
+exception will be thrown in the case of error.
+
+=head2 $ident-E<gt>error_type
+
+The error type returned by the ident server, if an error
+happened.  Only useful in non-blocking mode, as in blocking
+mode an exception will be thrown in the case of error.
+
 =head1 METHODS
 
 =head2 $ident-E<gt>same_user
@@ -93,7 +96,8 @@ matches either the server's username or real uid.
 
 =head1 SEE ALSO
 
-L<Mojolicious::Plugin::Ident>
+L<Mojolicious::Plugin::Ident>,
+L<AnyEvent::Ident::Response>
 
 =head1 AUTHOR
 
